@@ -18,14 +18,6 @@ class AccessDenied(ExceptionBase):
     message: str = "Access denied"
 
 
-@dataclass
-class UnknownAppEntityType(ExceptionBase):
-    """Raised when an unknown app entity type is requested."""
-
-    def __init__(self, app_entity_type: str):
-        self.message = f"Unknown app entity: {app_entity_type}!"
-
-
 @dataclass
 class UserNotFound(ExceptionBase):
     """Raised when a user is not found."""
