@@ -36,7 +36,11 @@ class BaseUseCase(UseCasePort):
         assert role in self.roles, f"Role does not exist: {role}"
 
     def _get_allowed_app_entity_records_identifiers(
-        self, user, role: ChoiceEnum, app_entity_type: str, permission: str = None
+        self,
+        user,
+        role: ChoiceEnum,
+        app_entity_type: str,
+        permission: str = None,
     ) -> list[Any] | Literal[ALL]:
         """
         Gets the identifiers of the app entity records that the user can access.
@@ -50,30 +54,33 @@ class BaseUseCase(UseCasePort):
         Returns:
             List of identifiers of App Entity Records that the user can access
         """
-        self._verify_role(role)
-        self._verify_app_entity_type(app_entity_type)
 
-        user_role = self.users_unit_of_work.user_role_repository.get_first(
-            user_id=user.id, role=role
-        )
-        if not user_role:
-            return []
+        with self.users_unit_of_work as uow:
+            self._verify_role(role)
+            self._verify_app_entity_type(app_entity_type)
 
-        # Permission restriction get precedence, if existing, for the given app_entity
-        if permission:
-            permission_restrictions = user_role.permission_restrictions
-            if permission_restrictions and permission in permission_restrictions.keys():
-                permission_restriction = permission_restrictions.get(permission)
-                if permission_app_entity_restriction := permission_restriction.get(
-                    app_entity_type
+            user_role = uow.user_role_repository.get_first(user_id=user.id, role=role)
+            if not user_role:
+                return []
+
+            # Permission restriction get precedence, if existing, for the given app_entity
+            if permission:
+                permission_restrictions = user_role.permission_restrictions
+                if (
+                    permission_restrictions
+                    and permission in permission_restrictions.keys()
                 ):
-                    return permission_app_entity_restriction
+                    permission_restriction = permission_restrictions.get(permission)
+                    if permission_app_entity_restriction := permission_restriction.get(
+                        app_entity_type
+                    ):
+                        return permission_app_entity_restriction
 
-        # Verify if there is any restriction on the entity for the user
-        app_entities_restrictions = user_role.app_entities_restrictions
-        if app_entities_restrictions and (
-            app_entity_restriction := app_entities_restrictions.get(app_entity_type)
-        ):
-            return app_entity_restriction
+            # Verify if there is any restriction on the entity for the user
+            app_entities_restrictions = user_role.app_entities_restrictions
+            if app_entities_restrictions and (
+                app_entity_restriction := app_entities_restrictions.get(app_entity_type)
+            ):
+                return app_entity_restriction
 
-        return ALL
+            return ALL
