@@ -68,7 +68,7 @@ class UsersModuleDIContainer(containers.DeclarativeContainer):
     event_producer = providers.Dependency()
     users_unit_of_work = providers.Factory(
         unit_of_work.UsersUnitOfWork,
-        session=database.provided.session,
+        session_maker=database.provided.session_factory,
     )
     use_cases = providers.Container(
         UsersModuleUseCasesDIContainer,
