@@ -14,9 +14,9 @@ class GetUserUseCase(UseCasePort):
 
     def execute(self, /, username: str) -> User:
         """Get user by username."""
-        user: User = self.users_unit_of_work.user_repository.get_first(
-            username=username
-        )
-        if user is None:
-            raise UserNotFound(username)
-        return user
+        with self.users_unit_of_work as uow:
+            user: User = uow.user_repository.get_first(username=username)
+            if user is None:
+                raise UserNotFound(username)
+
+            return user
