@@ -16,5 +16,5 @@ class UserRoleModel(Base, BaseModelMixin):
 
     user_id = Column(UUID(), ForeignKey("users.id"))
     role = Column(String(40), nullable=False)
-    app_entities_restrictions = Column(JsonField(), nullable=False)
-    permission_restrictions = Column(JsonField(), nullable=False)
+    app_entities_restrictions = Column(JsonField(), nullable=True)
+    permission_restrictions = Column(JsonField(), default=dict)
