@@ -7,7 +7,7 @@ from idp_authentication.conftest import (
 
 def test_get_allowed_app_entity_records_with_permission(container, user):
     get_allowed_app_entity_records = (
-        container.users_module().use_cases().get_allowed_app_entity_records_use_case()
+        container.users_module().use_cases().get_allowed_record_identifiers_use_case()
     )
     records = get_allowed_app_entity_records.execute(
         user=user,
@@ -20,7 +20,7 @@ def test_get_allowed_app_entity_records_with_permission(container, user):
 
 def test_get_allowed_app_entity_records_with_no_permission(container, user_2):
     get_allowed_app_entity_records = (
-        container.users_module().use_cases().get_allowed_app_entity_records_use_case()
+        container.users_module().use_cases().get_allowed_record_identifiers_use_case()
     )
     records = get_allowed_app_entity_records.execute(
         user=user_2,
