@@ -2,7 +2,7 @@ from dataclasses import asdict
 
 import pytest
 
-from idp_authentication import UserRole
+from idp_authentication import User, UserRole
 from idp_authentication.conftest import TEST_PERMISSION, TEST_ROLE_1, TEST_ROLE_2
 
 
@@ -19,7 +19,9 @@ def test_user_role_create(container, user, user_role, expected_role):
     new_role = UserRole(role=user_role, app_entities_restrictions={}, user_id=user.id)
     user_as_dict["user_roles"] = new_role
     process_user.execute(user_as_dict)
-    assert user.user_roles[0].role == expected_role
+    session = container.database.provided().session
+    updated_user = session.query(User).filter(User.id == user.id).first()
+    assert updated_user.user_roles[0].role == expected_role
 
 
 @pytest.mark.parametrize(
@@ -33,7 +35,10 @@ def test_user_role_create(container, user, user_role, expected_role):
 def test_user_role_update(container, user, user_role, expected_role):
     process_user, user_as_dict = process_user_use_case(container, user, user_role)
     process_user.execute(user_as_dict)
-    assert user.user_roles[0].role == expected_role
+    session = container.database.provided().session
+    updated_user = session.query(User).filter(User.id == user.id).first()
+
+    assert updated_user.user_roles[0].role == expected_role
 
 
 def test_process_user_deletes_user_roles_when_user_has_no_access_in_app(
@@ -49,9 +54,9 @@ def test_process_user_deletes_user_roles_when_user_has_no_access_in_app(
 
     # Assert
     users_unit_of_work = container.users_module().users_unit_of_work()
-    db_user = users_unit_of_work.user_repository.get_or_none(username=user.username)
-
-    assert db_user.user_roles == []
+    with users_unit_of_work:
+        db_user = users_unit_of_work.user_repository.get_or_none(username=user.username)
+        assert db_user.user_roles == []
 
 
 def process_user_use_case(container, user, user_role, app_identifier="test"):
