@@ -1,6 +1,6 @@
 import pytest
 
-from idp_authentication.conftest import MockEventProducer
+from idp_authentication.users.tests.mock_event_producer import MockEventProducer
 
 
 @pytest.mark.parametrize(
